<?php
class Bootstrap
{
    public function __construct($configSection = 'live')
    {
        $rootDir = dirname(dirname(__FILE__));
        define('ROOT_DIR', $rootDir);

        set_include_path(get_include_path()
            . PATH_SEPARATOR . ROOT_DIR . '/library/'
            . PATH_SEPARATOR . ROOT_DIR . '/application/models/'
	    );
        
        include 'Zend/Loader.php';
        Zend_Loader::registerAutoload();

        // Load configuration
        Zend_Registry::set('configSection', $configSection);
        $config = new Zend_Config_Ini(ROOT_DIR.'/application/config.ini', $configSection);
        Zend_Registry::set('config', $config);
        
        date_default_timezone_set($config->date_default_timezone);
        
        // configure database and store to the registery
        $db = Zend_Db::factory($config->db);
        Zend_Db_Table_Abstract::setDefaultAdapter($db);
        Zend_Registry::set('db', $db);
        
        $writer = new Zend_Log_Writer_Stream(ROOT_DIR . '/tmp/log.txt');
        $logger = new Zend_Log($writer);
        Zend_Registry::set('logger', $logger);
    }

    public function runApp()
    {
        // setup front controller
        $frontController = Zend_Controller_Front::getInstance();
        $frontController->throwExceptions(false);
        $frontController->setControllerDirectory(ROOT_DIR . '/application/controllers');
        $frontController->addModuleDirectory(ROOT_DIR . '/application/modules');
        
        $frontController->registerPlugin(new Places_Controller_Plugin_ModelDirSetup());
        $frontController->registerPlugin(new Places_Controller_Plugin_ActionSetup());
        $frontController->registerPlugin(new Places_Controller_Plugin_ViewSetup(), 98);
        
        
        //example of setting up a route
        $defaults = array(
            'module'=>'news', 
            'controller'=>'index',
            'action'=>'view');
        $newsRoute = new Zend_Controller_Router_Route('news/:id', $defaults);
        
        $router = $frontController->getRouter();
        $router->addRoute('news', $newsRoute);
        
        $defaults = array(
            'module'=>'news', 
            'controller'=>'index',
            'action'=>'view', 
            'year'=>2008);
        $requirements = array('year'=>'\d{4}');
        $archiveRoute = new Zend_Controller_Router_Route('news/archive/:year', 
            $defaults, $requirements);
        
        $router = $frontController->getRouter();
        $router->addRoute('newsArchive', $archiveRoute);
        
        
        $defaults = array(
            'module'=>'default', 
            'controller'=>'auth',
            'action'=>'login'); 
        
        $loginRoute = new Zend_Controller_Router_Route_Static('login', 
            $defaults);
            
        $router = $frontController->getRouter();
        $router->addRoute('login', $loginRoute);
                
        
        
                
        $defaults = array(
            'module'=>'news', 
            'controller'=>'index',
            'action'=>'view');
        $archiveRoute = new Zend_Controller_Router_Route_Regex('news/archive/(\d{4})', 
            $defaults);
            
        
        
        // setup the layout
        Zend_Layout::startMvc(array(
            'layoutPath' => ROOT_DIR . '/application/views/layouts',
        ));
        
        // run!
        try {
            $frontController->dispatch();
            
            $logger = Zend_Registry::get('logger');
            $db = Zend_Registry::get('db');
            
            $profiler = $db->getProfiler();
            $totalTime    = $profiler->getTotalElapsedSecs() * 1000;
            $queryCount   = $profiler->getTotalNumQueries();
            
            foreach ($profiler->getQueryProfiles() as $i=>$query) {
                $ms = $query->getElapsedSecs() * 1000;
                
                $msg = $i . ' - Query: "' . $query->getQuery() . '"';
                $msg .= ', Params: ' . implode(',', $query->getQueryParams());
                $msg .= ', Time: ' . number_format($ms, 3). ' ms';
                
                $messages[] = $msg;
                
            }
            
            $log = $queryCount . ' queries in ' . number_format($totalTime, 3) 
                . ' milliseconds' . "\n";
            
            $log .= "Queries:\n";
            $log .= implode("\n", $messages);
            
            echo "<pre>";
            $logger->debug($log);
            
            
        } catch (Exception $exception) {
            // an exception has occurred after the ErrorController's postdispatch() has run
            if(Zend_Registry::get('config')->debug == 1) {
                $msg = $exception->getMessage(); 
                $trace = $exception->getTraceAsString();
                echo "<div>Error: $msg<p><pre>$trace</pre></p></div>"; 
            } else {
                try {
                    $logFile = Zend_Registry::get('config')->logFiles->error;
                    $log = new Zend_Log(new Zend_Log_Writer_Stream($logFile));
                    $log->debug($exception->getMessage() . "\n" .  $exception->getTraceAsString() . "\n-----------------------------");
                } catch (Exception $e) {
                    // can't log it - display error message
                    die("<p>An error occurred with logging an error!");
                }
            }
        }
    }

}