<?php

class ZFiATestConfiguration
{

	static function initialiseTests($chapterDirectory)
	{
		require_once 'PHPUnit/Framework/TestSuite.php';
		require_once 'PHPUnit/TextUI/TestRunner.php';

		set_include_path('.'
		. PATH_SEPARATOR . $chapterDirectory . '/../lib'
		. PATH_SEPARATOR . '.' . PATH_SEPARATOR . get_include_path());

		include_once 'Zend/Loader.php';
		Zend_Loader::registerAutoload();

		// database connection
		$adapter ='PDO_MYSQL';
		$config = array('host'=>'localhost',
                            'username'=>'zfia',
                            'password'=>'zfia',
                            'dbname'=>'places_test');

		date_default_timezone_set('UTC');
		
		// set up database
		$db = Zend_Db::factory($adapter, $config);
		Zend_Db_Table::setDefaultAdapter($db);
		Zend_Registry::set('db', $db);
		self::initialiseDatabase();

	}



	static function initialiseDatabase()
	{
		$db = Zend_Registry::get('db'); /* @var $db Zend_Db_Adapter_Abstract */

		$db->query(<<<EOT
	DROP TABLE IF EXISTS users;
EOT
	);

	$db->query(<<<EOT
	CREATE TABLE users (
	id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
	date_created DATETIME NULL ,
	date_updated DATETIME NULL ,

	first_name VARCHAR( 100 ) NOT NULL ,
	surname VARCHAR( 100 ) NOT NULL ,
	date_of_birth datetime NULL,
	sex char(1) NULL,

	address1 VARCHAR( 100 ) NULL ,
	address2 VARCHAR( 100 ) NULL ,
	address3 VARCHAR( 100 ) NULL ,
	town VARCHAR( 75 ) NULL ,
	county VARCHAR( 75 ) NULL ,
	country VARCHAR( 75 ) NULL ,
	postcode VARCHAR( 30 ) NULL
	)
EOT
	);


	$row = array (
		'first_name' => 'Rob',
		'surname'  => 'Allen',
		'date_of_birth' => '1970-01-04',
		'sex' => 'M',
		'town' => 'Worcester',
		'country' => 'UK',
		'date_created' => '2007-02-14 00:00:00',
		'date_updated' => '2007-02-14 00:00:00'
	);

	$db->insert('users', $row);


	$row = array (
		'first_name' => 'Julie',
		'surname'  => 'Smith',
		'date_of_birth' => '1981-03-15',
		'sex' => 'F',
		'town' => 'London',
		'country' => 'UK',
		'date_created' => '2007-02-14 00:00:00',
		'date_updated' => '2007-02-14 00:00:00'
	);

	$db->insert('users', $row);

	$row = array (
		'first_name' => 'Jane',
		'surname'  => 'Doe',
		'date_of_birth' => '1971-02-25',
		'sex' => 'F',
		'town' => 'London',
		'country' => 'UK',
		'date_created' => '2007-02-14 00:00:00',
		'date_updated' => '2007-02-14 00:00:00'
	);

	$db->insert('users', $row);

	}
	
	static function initialiseRelationshipDatabase()
	{
	    $db = Zend_Registry::get('db'); /* @var $db Zend_Db_Adapter_Abstract */
	    
	    
	    $db->query(<<<EOT
DROP TABLE IF EXISTS places;
EOT
);

$db->query(<<<EOT
CREATE TABLE places (
id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
date_created DATETIME NOT NULL ,
date_updated DATETIME NOT NULL ,
name VARCHAR( 100 ) NOT NULL ,
address1 VARCHAR( 100 ) NULL ,
address2 VARCHAR( 100 ) NULL ,
address3 VARCHAR( 100 ) NULL ,
town VARCHAR( 75 ) NULL ,
county VARCHAR( 75 ) NULL ,
postcode VARCHAR( 30 ) NULL ,
country VARCHAR( 75 ) NULL
)
EOT
);

$db->query(<<<EOT
DROP TABLE IF EXISTS reviews;
EOT
);

$db->query(<<<EOT
CREATE TABLE reviews (
id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
date_created DATETIME NOT NULL ,
date_updated DATETIME NOT NULL ,
place_id INT NOT NULL ,
user_id INT NOT NULL ,
body MEDIUMTEXT NOT NULL ,
rating INT NULL,
approved_by INT
);
EOT
);

$row = array (
	'first_name' => 'John',
	'surname'  => 'Smith',
	'date_of_birth' => '1964-01-01',
	'sex' => 'M',
	'town' => 'London',
	'country' => 'UK',
	'date_created' => '2007-02-14 00:00:00',
	'date_updated' => '2007-02-14 00:00:00'
);

$db->insert('users', $row);

$db->getConnection()->query(<<<EOT
INSERT INTO places (name, address1, town, county, postcode, date_created, date_updated)
VALUES 
('London Zoo', 'Regent\'s Park', 'London', '', 'NW1 4RY', '2007-02-14 00:00:00', '2007-02-14 00:00:00')
,('Alton Towers', 'Regent\'s Park', 'Alton', 'Staffordshire', 'ST10 4DB', '2007-02-14 00:00:00', '2007-02-14 00:00:00')
,('Coughton Court', '', 'Alcester', 'Warwickshire', 'B49 5JA', '2007-02-14 00:00:00', '2007-02-14 00:00:00')
;
EOT
);

$db->getConnection()->query(<<<EOT
INSERT INTO reviews  (place_id, user_id, body, rating, date_created, date_updated, approved_by)
VALUES
(1, 2, 'The facilities here are really good. All the family enjoyed it', 4, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 4)
,(1, 1, 'Good day out, but not so many big animals now.', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 2)
,(1, 2, 'Excellent food in the cafeteria. Even my 2 year old ate her lunch!', 4, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 2)
,(2, 1, 'Good for teenagers!', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 2)
,(2, 1, 'A great family day out, but lots of queues!', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 2)
,(2, 2, 'A fun day was had by our family!', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 2)
,(3, 1, 'Our children enjoyed learning some of the history!', 3, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 2)
;
EOT
);
	}
}