<?php

require_once 'PHPUnit/Framework.php';

define('CHAPTER_DIRECTORY', dirname(dirname(__FILE__)));
require_once CHAPTER_DIRECTORY.'/TestConfiguration.php';
ZFiATestConfiguration::initialiseTests(CHAPTER_DIRECTORY);


class insertUpdateDeleteTest extends PHPUnit_Framework_TestCase
{
    public function setUp()
    {
        // reset database to know state
        ZFiATestConfiguration::initialiseDatabase();
        $this->db = Zend_Registry::get('db');
    }

    public function testInsert()
    {
        $db =& $this->db; /* @var $db Zend_Db_Adapter_Abstract */
        $sql = 'SELECT * FROM users';
		$result = $this->db->query($sql);  /* @var $result PDOStatement */
        $rows = $result->fetchAll();
        $this->assertSame(3, count($rows));
        
        // insert a user
        $data = array(
            'date_created' => date('Y-m-d'),
            'date_updated' => date('Y-m-d'),
        	'first_name' => 'Ben',
        	'surname' => 'Ramsey'
        );

        $table = 'users';
        $rows_affected = $db->insert($table, $data);
        $last_insert_id = $db->lastInsertId();
        $this->assertSame(4, (int)$last_insert_id);
    }

    public function testUpdate()
    {
        $db =& $this->db; /* @var $db Zend_Db_Adapter_Abstract */
        
        $sql = "SELECT * FROM users where country = 'UK'";
		$result = $this->db->query($sql);  /* @var $result PDOStatement */
		$rows = $result->fetchAll();
        $this->assertSame(3, count($rows));
        
        // update country
        $data = array(
            'country' => 'United Kingdom'
        );
        $table = 'users';
        $where = $db->quoteInto('country = ?', 'UK');
        $rows_affected = $db->update($table, $data, $where);

        // ensure that there are no more country = UK rows
        $sql2 = "SELECT * FROM users where country = 'UK'";
		$result2 = $this->db->query($sql2);  /* @var $result PDOStatement */
		$rows2 = $result2->fetchAll();
        $this->assertSame(0, count($rows2));

        $sql3 = "SELECT * FROM users where country = 'United Kingdom'";
		$result3 = $this->db->query($sql3);  /* @var $result PDOStatement */
		$rows3 = $result3->fetchAll();
        $this->assertSame(3, count($rows3));
        
    }
    
    public function testDelete()
    {
        $db =& $this->db; /* @var $db Zend_Db_Adapter_Abstract */
        
        $sql = "SELECT * FROM users where country = 'UK'";
		$result = $this->db->query($sql);  /* @var $result PDOStatement */
		$rows = $result->fetchAll();
        $this->assertSame(3, count($rows));
        
        // delete user 1
        $table = 'users';
        $where = 'id = 1';
        $rows_affected = $db->delete($table, $where);

        $sql2 = "SELECT * FROM users where country = 'UK'";
		$result2 = $this->db->query($sql2);  /* @var $result PDOStatement */
		$rows2 = $result2->fetchAll();
        $this->assertSame(2, count($rows2));
    }    
}
