<?php

require_once 'PHPUnit/Framework.php';

define('CHAPTER_DIRECTORY', dirname(dirname(__FILE__)));
require_once CHAPTER_DIRECTORY . '/TestConfiguration.php';
ZFiATestConfiguration::initialiseTests(CHAPTER_DIRECTORY);


class Places extends Zend_Db_Table_Abstract
{
    protected $_name = 'places';
    protected $_dependentTables = array('Reviews');
}

class Reviews extends Zend_Db_Table_Abstract
{
    protected $_name = 'reviews';
    protected $_referenceMap    = array(
        'Place' => array(
            'columns'           => array('place_id'),
            'refTableClass'     => 'Places',
            'refColumns'        => array('id')
        ),
        'User' => array(
            'columns'           => array('user_id'),
            'refTableClass'     => 'Users',
            'refColumns'        => array('id')
        ),
        'ApprovedBy' => array(
            'columns'           => array('approved_by'),
            'refTableClass'     => 'Users',
            'refColumns'        => array('id')
        )
    );
}

class Users extends Zend_Db_Table_Abstract
{
    protected $_name = 'users';
    protected $_dependentTables = array('Reviews');
}

class manyToManyTest extends PHPUnit_Framework_TestCase
{
    public function setUp()
    {
        // reset database to know state
        ZFiATestConfiguration::initialiseRelationshipDatabase();
        $this->db = Zend_Registry::get('db');
    }

    public function testFetchPlaces()
    {
        $places = new Places();

        $londonZoo = $places->fetchRow('id = 1');
        $reviews = $londonZoo->findDependentRowset('Reviews');

        $this->assertSame(3, count($reviews));
    }

    public function testFetchUsers()
    {
        $users = new Users();

        $robAllen = $users->fetchRow('id = 1');
        $reviews = $robAllen->findDependentRowset('Reviews');

        $this->assertSame(4, count($reviews));
    }

    public function testManyToMany()
    {
        $users = new Users();
        $robAllen = $users->fetchRow('id = 1');
        
        
        $reviews = new Reviews();
        $intersectionTableName = 'reviews';
        $intersectionForeignFieldKeyName = 'place_id';
        $matchTableName = 'places';
        $matchTablePrimaryKey = 'id';
        
        $joinCondition = $intersectionTableName.'.id';
        $select = new Zend_Db_Select($this->db);
        $select->distinct(true);
        $select->from($intersectionTableName);
        $select->join($matchTableName, $joinCondition, '*');

        // find all places that Rob Allen has been to.
        $places = $robAllen->findManyToManyRowset('Places', 'Reviews');
        $this->assertSame(4, count($places));
    }


}

