<?php

class AuthController extends Zend_Controller_Action
{
    protected $_redirectUrl = '/';

    public function init()
    {
        $this->_helper->acl->allow(null);
    }
    
    public function indexAction()
    {
        $this->_forward('login');
    }

    public function loginAction()
    {
        $this->view->title = 'Log in';
        $flashMessenger = $this->_helper->FlashMessenger;
        $flashMessenger->setNamespace('actionErrors');
        $this->view->actionErrors = $flashMessenger->getMessages();
    }

    public function logoutAction()
    {
        $auth = Zend_Auth::getInstance();
        $auth->clearIdentity();
        $this->_redirect('/');
    }

    public function privilegesAction()
    {
        $this->_forward('login');
    }
    
    public function identifyAction()
    {
        if ($this->getRequest()->isPost()) {
            // collect the data from the user
            $formData = $this->_getFormData();
        
            if (empty($formData['username']) 
                    || empty($formData['password'])) {
                $this->_flashMessage('Please provide a username and password.');
            } else {
                // do the authentication
                $authAdapter = $this->_getAuthAdapter($formData);
                $auth = Zend_Auth::getInstance();
                $result = $auth->authenticate($authAdapter);
                if (!$result->isValid()) {
                    $this->_flashMessage('Login failed');
                } else {
                    // success: store database row to auth's storage 
                    // (Not the password though!)
                    $data = $authAdapter->getResultRowObject(null, 
                                'password');
                    $auth->getStorage()->write($data);

                    $this->_redirect($this->_redirectUrl);
                    return;
                }
            }
        }
        
        $this->_redirect('/auth/login');
    }
    
    protected function _flashMessage($message) {
        $flashMessenger = $this->_helper->FlashMessenger;
        $flashMessenger->setNamespace('actionErrors');
        $flashMessenger->addMessage($message);
    }
    
    /**
     * Retrieve the login form data from _POST
     *
     * @return array
     */
    protected function _getFormData()
    {
        $data = array();
        $filterChain = new Zend_Filter;
        $filterChain->addFilter(new Zend_Filter_StripTags);
        $filterChain->addFilter(new Zend_Filter_StringTrim);
        
        $data['username'] = $filterChain->filter(
            $this->getRequest()->getPost('username'));
        $data['password'] = $filterChain->filter(
            $this->getRequest()->getPost('password'));

        return $data;
    }
    
    /**
     * Set up the auth adapater for interaction with the database
     *
     * @return Zend_Auth_Adapter_DbTable
     */
    protected function _getAuthAdapter($formData)
    {
        $dbAdapter = Zend_Registry::get('db');
        $authAdapter = new Zend_Auth_Adapter_DbTable($dbAdapter);
        $authAdapter->setTableName('users')
                    ->setIdentityColumn('username')
                    ->setCredentialColumn('password')
                    ->setCredentialTreatment('SHA1(?)');

        // get "salt" for better security
        $config = Zend_Registry::get('config');
        $salt = $config->auth->salt;
        $password = $salt.$formData['password'];
        
        $authAdapter->setIdentity($formData['username']);
        $authAdapter->setCredential($password);

        return $authAdapter;
    }
    
}
