<?php

class AuthController extends Zend_Controller_Action
{
    protected $_redirectUrl = '/';

    public function init()
    {
        $this->_helper->acl->allow(null);
    }
    
    public function indexAction()
    {
        // If user isn't logged in, show login form
        if (null === Zend_Auth::getInstance()->getIdentity()) {
            $this->_helper->redirector->gotoRouteAndExit(array('action'=>'form'));
        } else {
            $this->_redirect('/');
        }
    }

    public function formAction()
    {
        // This is the new login form used after chapter 8 (Forms)
        // It authorises the user via a validator (Places_Validate_Authorise)
        
        $form = new LoginFormDecorated();
        $form->setAction($this->view->baseUrl() .'/auth/form/');
        $this->view->formResponse = '';
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($_POST)) {
                // Retrieve the auth adapter from Places_Validate_Authorise
                // via the username form element
                $authAdapter = $form->username->getValidator('Authorise')->getAuthAdapter();

                // success: store database row to auth's storage 
                // (Not the password though!)
                $data = $authAdapter->getResultRowObject(null, 
                            'password');
                $auth = Zend_Auth::getInstance();
                $auth->getStorage()->write($data);
                $this->_redirect($this->_redirectUrl);
            } else {
                // ensure that the Auth adapter is cleared
                $auth = Zend_Auth::getInstance();
                $auth->clearIdentity();
        
                $this->view->formResponse = 'Sorry, there was a problem with your submission. Please check the following:';
                // Cheat for the translated bit
                //$this->view->formResponse = 'Entschuldigung, es gab ein Problem mit Ihrer Eingabe. Überprüfen Sie bitte das folgende:';
                $form->populate($_POST);
            }
        } 
        
        $this->view->form = $form;
    }

    public function logoutAction()
    {
        $auth = Zend_Auth::getInstance();
        $auth->clearIdentity();
        $this->_redirect('/');
    }
}