<?php
class Bootstrap
{
    public function __construct($configSection = 'live')
    {
        $rootDir = dirname(dirname(__FILE__));
        define('ROOT_DIR', $rootDir);

        set_include_path(get_include_path()
            . PATH_SEPARATOR . ROOT_DIR . '/library/'
            . PATH_SEPARATOR . ROOT_DIR . '/application/models/'
        );
        
        include 'Zend/Loader.php';
        Zend_Loader::registerAutoload();

        // Load configuration
        Zend_Registry::set('configSection', $configSection);
        $config = new Zend_Config_Ini(ROOT_DIR.'/application/configuration/config.ini', $configSection);
        Zend_Registry::set('config', $config);
        
        date_default_timezone_set($config->date_default_timezone);
        
        // configure database and store to the registery
        $db = Zend_Db::factory($config->db);
        Zend_Db_Table_Abstract::setDefaultAdapter($db);
        Zend_Registry::set('db', $db);
        
    }

    public function runApp()
    {
        // setup search indexer observer on the database rows
        SearchIndexer::setIndexDirectory(ROOT_DIR . '/var/search_index');
        Places_Db_Table_Row_Observable::attachObserver('SearchIndexer');

        // setup front controller
        $frontController = Zend_Controller_Front::getInstance();
        $frontController->throwExceptions(false);
        $frontController->setControllerDirectory(ROOT_DIR . '/application/controllers');
        
        $frontController->registerPlugin(new Places_Controller_Plugin_ActionSetup());
        $frontController->registerPlugin(new Places_Controller_Plugin_ViewSetup(), 98);
        
        // setup the layout
        Zend_Layout::startMvc(array(
            'layoutPath' => ROOT_DIR . '/application/views/layouts',
        ));
        
        // acl action helper
        $acl = new Places_Acl();
        $aclHelper = new Places_Controller_Action_Helper_Acl(null, array('acl'=>$acl));
        Zend_Controller_Action_HelperBroker::addHelper($aclHelper);
        
        // run!
        try {
            $frontController->dispatch();
        } catch (Exception $exception) {
            // an exception has occurred after the ErrorController's postdispatch() has run
            if(Zend_Registry::get('config')->debug == 1) {
                $msg = $exception->getMessage(); 
                $trace = $exception->getTraceAsString();
                echo "<div>Error: $msg<p><pre>$trace</pre></p></div>"; 
            } else {
                try {
                    $logFile = Zend_Registry::get('config')->logFiles->error;
                    $log = new Zend_Log(new Zend_Log_Writer_Stream($logFile));
                    $log->debug($exception->getMessage() . "\n" .  $exception->getTraceAsString() . "\n-----------------------------");
                } catch (Exception $e) {
                    // can't log it - display error message
                    die("<p>An error occurred with logging an error!");
                }
            }
        }
    }

}
