<?php

function initialiseTests()
{
    require_once 'PHPUnit/Framework/TestSuite.php';
    require_once 'PHPUnit/TextUI/TestRunner.php';

    set_include_path('.'
    . PATH_SEPARATOR . ROOT_DIR . '/library'
    . PATH_SEPARATOR . ROOT_DIR . '/../../lib'
    . PATH_SEPARATOR . ROOT_DIR . '/application/models'
    . PATH_SEPARATOR . '.' . PATH_SEPARATOR . get_include_path());

    include_once 'Zend/Loader.php';
    Zend_Loader::registerAutoload();
        
    // load configuration
    $section = 'test';
    $config = new Zend_Config_Ini(ROOT_DIR .'/application/configuration/config.ini', $section);
    Zend_Registry::set('config', $config);
    
    date_default_timezone_set('UTC');

    // set up database
    $db = Zend_Db::factory($config->db);
    Zend_Db_Table::setDefaultAdapter($db);
    Zend_Registry::set('db', $db);
    setupDatabase($db);

}



/**
 * @param Zend_Db_Adapter_Abstract $db
 */
function setupDatabase($db)
{
    $db->query(<<<EOT
DROP TABLE IF EXISTS places;
EOT
);

$db->query(<<<EOT
CREATE TABLE places (
id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
date_created DATETIME NOT NULL ,
date_updated DATETIME NOT NULL ,
name VARCHAR( 100 ) NOT NULL ,
address1 VARCHAR( 100 ) NULL ,
address2 VARCHAR( 100 ) NULL ,
town VARCHAR( 75 ) NULL ,
county VARCHAR( 75 ) NULL ,
postcode VARCHAR( 30 ) NULL ,
country VARCHAR( 75 ) NULL
)
EOT
);

$db->query(<<<EOT
DROP TABLE IF EXISTS reviews;
EOT
);

$db->query(<<<EOT
CREATE TABLE reviews (
id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
date_created DATETIME NOT NULL ,
date_updated DATETIME NOT NULL ,
created_by INT DEFAULT -1,
place_id INT NOT NULL ,
body MEDIUMTEXT NOT NULL ,
rating INT NULL ,
helpful_yes INT NOT NULL DEFAULT 0 ,
helpful_total INT NOT NULL DEFAULT 0
);
EOT
);

$db->query(<<<EOT
INSERT INTO places (name, address1, town, county, postcode, date_created, date_updated)
VALUES 
(?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?)
;
EOT
, array(
'London Zoo', 'Regent\'s Park', 'London', '', 'NW1 4RY', '2007-02-14 00:00:00', '2007-02-14 00:00:00',
'Alton Towers', 'Regent\'s Park', 'Alton', 'Staffordshire', 'ST10 4DB', '2007-02-14 00:00:00', '2007-02-14 00:00:00',
'Coughton Court', '', 'Alcester', 'Warwickshire', 'B49 5JA', '2007-02-14 00:00:00', '2007-02-14 00:00:00'
)
);

$db->query(<<<EOT
INSERT INTO reviews  (created_by, place_id, body, rating, date_created, date_updated, helpful_yes, helpful_total)
VALUES
 (?, ?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?, ?)
,(?, ?, ?, ?, ?, ?, ?, ?)
EOT
, array(
 1, 1, 'The facilities here are really good. All the family enjoyed it', 4, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 3, 6
,2, 1, 'Good day out, but not so many big animals now.', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 4, 4
,3, 1, 'Excellent food in the cafeteria. Even my 2 year old ate her lunch!', 4, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 2, 5
,3, 2, 'Good for teenagers!', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 5, 6
,2, 2, 'A great family day out, but lots of queues!', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 7, 10
,1, 2, 'A fun day was had by our family!', 2, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 8, 12
,1, 3, 'Our children enjoyed learning some of the history!', 3, '2007-02-14 00:00:00', '2007-02-14 00:00:00', 23, 24
)
);

}