<?php

require_once 'PHPUnit/Framework.php';

require_once ROOT_DIR . '/application/controllers/IndexController.php';

class Helper_Acl extends Zend_Controller_Action_Helper_Abstract
{
    function allow()
    {
        // function to allow index controller to load - we aren't
        // testing ACL, so just swallow
    }
}

class IndexControllerTest extends PHPUnit_Framework_TestCase
{
    public function setUp()
    {
        Zend_Registry::set('Zend_Translate', null);
        
        $aclHelper = new Helper_Acl();
        Zend_Controller_Action_HelperBroker::addHelper($aclHelper);            

        $this->request = new Zend_Controller_Request_Http();
        $this->response = new Zend_Controller_Response_Cli();
        $this->controller = new IndexController($this->request,
            $this->response);
            
        $this->frontController = Zend_Controller_Front::getInstance();
        $this->frontController->resetInstance(); // reset the FC
        $this->frontController->setRequest($this->request);
        $this->frontController->setControllerDirectory(ROOT_DIR . '/application/controllers');
        $this->frontController->returnResponse(true);
        
        // clear the view as it stores a copy of the translator object
        $viewRenderer = Zend_Controller_Action_HelperBroker::getStaticHelper('ViewRenderer');
        if($viewRenderer->view) {
            $viewRenderer->view = null;
        }
        
        $config = Zend_Registry::get('config');
        $this->frontController->registerPlugin(new Places_Controller_Plugin_LanguageSetup( 
                ROOT_DIR . '/application/configuration/translations',
                $config->languages->toArray()));       

        Zend_Registry::set('Zend_Translate', null);
        
    }

    public function testIndexAction()
    {
        $this->request->setModuleName('index');
        $this->request->setControllerName('index');
        $this->request->setActionName('index');
        $response = $this->frontController->dispatch();
        $output = $response->getBody();
        $this->assertContains('Places to take the kids', $output);
        $this->assertContains('London Zoo', $output);
    }

    public function testDeIndexAction()
    {
        $this->request->setModuleName('index');
        $this->request->setControllerName('index');
        $this->request->setActionName('index');
        $this->request->setParam('lang', 'de');
        
        $response = $this->frontController->dispatch();
        $output = $response->getBody();
        $this->assertContains('Willkommen bei Places to take the kids!', $output);
        $this->assertContains('London Zoo', $output);
    }
    
}
